require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_wsmanconfig',
  dscmeta_resource_friendly_name: 'WSManConfig',
  dscmeta_resource_name: 'DSC_WSManConfig',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'WSManDsc',
  dscmeta_module_version: '3.1.1',
  docs: 'The DSC WSManConfig resource type.
         Automatically generated from version 3.1.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_maxtimeoutms: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the WS-Man maximum timeout in milliseconds. The minimum value is 500 and the maximum is 4294967295.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxenvelopesizekb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the WS-Man maximum envelope size in KB. The minimum value is 32 and the maximum is 4294967295.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_maxbatchitems: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the WS-Man maximum batch items. The minimum value is 1 and the maximum is 4294967295.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
